package com.gmei.data.monitor;

import com.gmei.data.monitor.operator.PortraitMonitorShdOperator;
import com.gmei.data.monitor.operator.PortraitMonitorSucOperator;
import com.gmei.data.monitor.source.PortraitKafkaSource;
import com.gmei.data.monitor.source.PortraitSucKafkaSource;
import org.apache.flink.api.common.restartstrategy.RestartStrategies;
import org.apache.flink.api.java.utils.ParameterTool;
import org.apache.flink.runtime.state.filesystem.FsStateBackend;
import org.apache.flink.streaming.api.TimeCharacteristic;
import org.apache.flink.streaming.api.datastream.DataStream;
import org.apache.flink.streaming.api.environment.CheckpointConfig;
import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;

/**
 * @ClassName PortraitMonitorMain
 * @Description: 画像打点实时监控主入口
 *
 * @Author zhaojianwei
 * @Date 2020/3/18
 * @Version V1.0
 **/
public class PortraitMonitorMainShd {

    public static void main(String[] args) throws Exception{
        // 获取运行参数
        ParameterTool parameterTool = ParameterTool.fromArgs(args);
        String inBrokers = parameterTool.get("inBrokers","test003:9092");
        String batchSize = parameterTool.get("batchSize","1000");
        String maidianInTopic = parameterTool.get("maidianInTopic", "test11");
        String backendInTopic = parameterTool.get("backendInTopic","test12");
        String portraitShdGroupId = parameterTool.get("portraitShdGroupId","flink_monitor_shd");
        Integer windowSize = parameterTool.getInt("windowSize",60);
        Integer slideSize = parameterTool.getInt("slideSize",60);
        String inJdbcUrl = parameterTool.get("inJdbcUrl",
                "jdbc:mysql://172.22.30.12:3306/zhengxing?user=work&password=zJnxVEhyyxeC7ciqxdMITVyWqOFc2mew&autoReconnect=true&useSSL=false");
        String outJdbcUrl = parameterTool.get("outJdbcUrl",
                "jdbc:mysql://test002:3306/flink_monitor?user=root&password=5OqYM^zLwotJ3oSo&autoReconnect=true&useSSL=false");
        Integer maxRetry = parameterTool.getInt("maxRetry",3);
        Long retryInteral = parameterTool.getLong("retryInteral",3000);
        String checkpointPath = parameterTool.get("checkpointPath","hdfs://bj-gmei-hdfs/user/data/flink/flink-monitor/checkpoint");
        Boolean isStartFromEarliest = parameterTool.getBoolean("isStartFromEarliest",false);
        Boolean isStartFromLatest = parameterTool.getBoolean("isStartFromLatest",false);
        String startTime = parameterTool.get("startTime");
        Integer parallelism = parameterTool.getInt("parallelism",2);

        // 获得流处理环境对象
        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
        env.setStreamTimeCharacteristic(TimeCharacteristic.EventTime);
        env.enableCheckpointing(1000);
        env.setStateBackend(new FsStateBackend(checkpointPath));
        env.setRestartStrategy(RestartStrategies.fixedDelayRestart(1, 3000));
        CheckpointConfig config = env.getCheckpointConfig();
        config.enableExternalizedCheckpoints(CheckpointConfig.ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION);

        DataStream portraitShdDataStream = new PortraitKafkaSource(
                env,
                inBrokers,
                maidianInTopic,
                backendInTopic,
                portraitShdGroupId,
                batchSize,
                isStartFromEarliest,
                isStartFromLatest,
                startTime
        ).getInstance();

        // 执行处理核心逻辑
        new PortraitMonitorShdOperator(portraitShdDataStream,windowSize,slideSize,inJdbcUrl,outJdbcUrl,maxRetry,retryInteral,parallelism).run();

        // 常驻执行
        env.execute("Portrait realtime monitor");
    }
}

