package com.gmei.data.monitor.callable;

import com.gmei.data.monitor.bean.DeviceInfo;
import com.gmei.data.monitor.common.Constants;
import com.gmei.data.monitor.utils.JDBCUtils;
import org.apache.flink.configuration.Configuration;

import java.sql.*;
import java.util.concurrent.Callable;

/**
 * ClassName: com.gmei.callable.CityCallable
 * Reason: 查询城市id
 * Date: 2020-03-03 00:00:00
 *
 * @author sjxuwei
 * @since JDK 1.8
 */
public class DeviceCallable implements Callable<DeviceInfo>{
    private Integer userId;
    private String inJdbcUrl;

    public DeviceCallable(Integer userId, String inJdbcUrl) {
        this.userId = userId;
        this.inJdbcUrl = inJdbcUrl;
    }

    @Override
    public DeviceInfo call() throws Exception {
        Connection connection = open();
        String deviceId = findDeviceId(userId, connection);
        close(connection);
        return new DeviceInfo(deviceId);
    }

    private Connection open() throws Exception {
        Class.forName(Constants.MYSQL_DRIVER_CLASS);
        return DriverManager.getConnection(inJdbcUrl);
    }

    private void close(Connection connection) throws Exception {
        JDBCUtils.close(connection,null,null);
    }

    private String findDeviceId(Integer userId, Connection connection) throws SQLException {
        Statement statement = connection.createStatement();
        ResultSet resultSet = statement.executeQuery(
                String.format(
                        "select device_id from statistic_device where id = (SELECT max(device_id) FROM statistic_device_user WHERE user_id = %d)",userId));
        String result = "";
        if(resultSet.next()){
            result = resultSet.getString(1);
        }
        JDBCUtils.close(null,statement,resultSet);
        return result;
    }
}
